Crate seedstore

Crate seedstore 

SeedStore is a solution for storing a BIP32-style master secret in a password-protected encrypted file. SeedStore is built on secretstore::SecretStore. A typical example is a wallet storing the secret seed.

If only a single key is needed, it it possible to use a single child key, or use KeyStore for a single key.

Structs

KeyStore
Store a single bitcoin-style ECDSA 32-byte private key in an encrypted file. The secret can be loaded from an encrypted file. Additionally store 4 bytes of non-secret data, reserved for later use.
KeyStoreCreator
Helper class for creating the store from given data. Should be used only by the utility that creates the encrypted file. See also KeyStore.
Options
Various config options for usage, such as allow weak password.
SeedStore
Store a secret BIP32-style entropy in an encrypted file. Can be loaded from an encrypted file. Additionally store a network type byte, and 3 bytes reserved for later use.
SeedStoreCreator
Helper class for creating the store from given data. Should be used only by the utility that creates the encrypted file. See also SeedStore.

Enums

ChildSpecifier
Various ways to specify a child key, e.g. by index or derivation path.