Crate seedstore

SeedStore is a solution for storing some bitcoin-related secret data in a password-protected encrypted file. A typical example is a wallet storing the secret seed.

Structs

KeyStore
Store a single bitcoin-style ECDSA 32-byte private key in an encrypted file. The secret can be loaded from an encrypted file. Additionally store as non-secret 4 bytes reserved for later use. The secret is stored in memory scrambled (using an ephemeral scrambling key).
KeyStoreCreator
Helper class for creating the store from given data. Should be used only by the utility that creates the encrypted file.
SeedStore
Store a secret BIP32-style entropy in an encrypted file Can be loaded from an encrypted file. Additionally store a network type byte, and 3 bytes reserved for later use. The secret is stored in memory scrambled (using an ephemeral scrambling key).
SeedStoreCreator
Helper class for creating the store from given data. Should be used only by the utility that creates the encrypted file.

Enums

ChildSpecifier
Various ways to specify a child, e.g. by index or derivation path.